@@ -4,7 +4,7 @@ class Node:
               id,
               title=None, # displayed if hovered
               label=None, # displayed inside the node
-              color="#ACDBC9",
+              color=None,
               shape="dot",
               size=25,
               **kwargs
@@ -18,7 +18,7 @@ class Node:
     self.shape=shape # # image, circularImage, diamond, dot, star, triangle, triangleDown, hexagon, square and icon
     self.size=size
     self.color=color #FDD2BS #F48B94 #F7A7A6 #DBEBC2
-    self.__dict__.update(kwargs)
+    self.__dict__.update(**kwargs)
 
   def to_dict(self):
     return self.__dict__
\ No newline at end of file
